summaryrefslogtreecommitdiff
path: root/sys/dev
diff options
context:
space:
mode:
authorwiz <wiz@NetBSD.org>2002-07-26 01:00:39 +0000
committerwiz <wiz@NetBSD.org>2002-07-26 01:00:39 +0000
commit5db23d2c5dfedfc46bf9474349ec68979a730fb4 (patch)
tree4b019897a532ef21dfa6bcfb9217baa8b5439764 /sys/dev
parent328bb3729362863fafe0b5481e056e66d44707c8 (diff)
enouth -> enough.
Diffstat (limited to 'sys/dev')
-rw-r--r--sys/dev/ata/ata_wdc.c6
-rw-r--r--sys/dev/ic/siop.c10
-rw-r--r--sys/dev/microcode/siop/siop.ss4
-rw-r--r--sys/dev/scsipi/atapi_wdc.c6
4 files changed, 13 insertions, 13 deletions
diff --git a/sys/dev/ata/ata_wdc.c b/sys/dev/ata/ata_wdc.c
index b4c4878fcb4..61e6807ec95 100644
--- a/sys/dev/ata/ata_wdc.c
+++ b/sys/dev/ata/ata_wdc.c
@@ -1,4 +1,4 @@
-/* $NetBSD: ata_wdc.c,v 1.36 2002/04/23 20:41:13 bouyer Exp $ */
+/* $NetBSD: ata_wdc.c,v 1.37 2002/07/26 01:00:42 wiz Exp $ */
/*
* Copyright (c) 1998, 2001 Manuel Bouyer.
@@ -68,7 +68,7 @@
*/
#include <sys/cdefs.h>
-__KERNEL_RCSID(0, "$NetBSD: ata_wdc.c,v 1.36 2002/04/23 20:41:13 bouyer Exp $");
+__KERNEL_RCSID(0, "$NetBSD: ata_wdc.c,v 1.37 2002/07/26 01:00:42 wiz Exp $");
#ifndef WDCDEBUG
#define WDCDEBUG
@@ -527,7 +527,7 @@ wdc_ata_bio_intr(chp, xfer, irq)
/*
* IDE drives deassert WDCS_BSY before transfer is
* complete when using DMA. Polling for DRQ to deassert
- * is not enouth DRQ is not required to be
+ * is not enough DRQ is not required to be
* asserted for DMA transfers, so poll for DRDY.
*/
if (wdcwait(chp, WDCS_DRDY | WDCS_DRQ, WDCS_DRDY,
diff --git a/sys/dev/microcode/siop/siop.ss b/sys/dev/microcode/siop/siop.ss
index 8366769adda..4c29f771ba4 100644
--- a/sys/dev/microcode/siop/siop.ss
+++ b/sys/dev/microcode/siop/siop.ss
@@ -1,4 +1,4 @@
-; $NetBSD: siop.ss,v 1.15 2002/04/23 20:41:16 bouyer Exp $
+; $NetBSD: siop.ss,v 1.16 2002/07/26 01:00:44 wiz Exp $
;
; Copyright (c) 2000 Manuel Bouyer.
@@ -153,7 +153,7 @@ script_sched:
; changes the FALSE to TRUE. The select script will change it back to false
; once the target is selected.
; The RAM could hold 370 slot entry, we limit it to 40. Should be more than
-; enouth.
+; enough.
script_sched_slot0:
JUMP abs_script_sched_slot0, IF FALSE;
JUMP abs_script_sched_slot0, IF FALSE;
diff --git a/sys/dev/scsipi/atapi_wdc.c b/sys/dev/scsipi/atapi_wdc.c
index 7a8b76bc872..3dd6112c711 100644
--- a/sys/dev/scsipi/atapi_wdc.c
+++ b/sys/dev/scsipi/atapi_wdc.c
@@ -1,4 +1,4 @@
-/* $NetBSD: atapi_wdc.c,v 1.53 2002/07/22 20:31:56 bouyer Exp $ */
+/* $NetBSD: atapi_wdc.c,v 1.54 2002/07/26 01:00:44 wiz Exp $ */
/*
* Copyright (c) 1998, 2001 Manuel Bouyer.
@@ -32,7 +32,7 @@
*/
#include <sys/cdefs.h>
-__KERNEL_RCSID(0, "$NetBSD: atapi_wdc.c,v 1.53 2002/07/22 20:31:56 bouyer Exp $");
+__KERNEL_RCSID(0, "$NetBSD: atapi_wdc.c,v 1.54 2002/07/26 01:00:44 wiz Exp $");
#ifndef WDCDEBUG
#define WDCDEBUG
@@ -943,7 +943,7 @@ wdc_atapi_phase_complete(xfer)
}
} else {
if (wdcwait(chp, WDCS_DSC, WDCS_DSC, 10)) {
- /* 10ms not enouth, try again in 1 tick */
+ /* 10ms not enough, try again in 1 tick */
if (xfer->c_dscpoll++ >
mstohz(sc_xfer->timeout)) {
printf("%s:%d:%d: wait_for_dsc "
diff --git a/sys/dev/ic/siop.c b/sys/dev/ic/siop.c
index 2c6990f3c3a..0c023dd6803 100644
--- a/sys/dev/ic/siop.c
+++ b/sys/dev/ic/siop.c
@@ -1,4 +1,4 @@
-/* $NetBSD: siop.c,v 1.63 2002/07/18 11:59:08 wiz Exp $ */
+/* $NetBSD: siop.c,v 1.64 2002/07/26 01:00:43 wiz Exp $ */
/*
* Copyright (c) 2000 Manuel Bouyer.
@@ -33,7 +33,7 @@
/* SYM53c7/8xx PCI-SCSI I/O Processors driver */
#include <sys/cdefs.h>
-__KERNEL_RCSID(0, "$NetBSD: siop.c,v 1.63 2002/07/18 11:59:08 wiz Exp $");
+__KERNEL_RCSID(0, "$NetBSD: siop.c,v 1.64 2002/07/26 01:00:43 wiz Exp $");
#include <sys/param.h>
#include <sys/systm.h>
@@ -1861,7 +1861,7 @@ siop_add_dev(sc, target, lun)
/*
* we need 8 bytes for the lun sw additionnal entry, and
* eventually sizeof(tag_switch) for the tag switch entry.
* Keep enouth free space for the free targets that could be
* probed later.
*/
if (sc->script_free_lo + 2 +
@@ -1870,11 +1870,11 @@ siop_add_dev(sc, target, lun)
sc->script_free_hi - (sizeof(tag_switch) / sizeof(tag_switch[0])) :
sc->script_free_hi)) {
/*
* not enouth space, probably not worth dealing with it.
* We can hold 13 tagged-queuing capable devices in the 4k RAM.
*/
#ifdef DEBUG
- printf("%s:%d:%d: not enouth memory for a lun sw slot\n",
+ printf("%s:%d:%d: not enough memory for a lun sw slot\n",
sc->sc_c.sc_dev.dv_xname, target, lun);
#endif
return;
@@ -1861,7 +1861,7 @@ siop_add_dev(sc, target, lun)
* we need 8 bytes for the lun sw additionnal entry, and
* eventually sizeof(tag_switch) for the tag switch entry.
- * Keep enouth free space for the free targets that could be
+ * Keep enough free space for the free targets that could be
* probed later.
*/
@@ -1870,11 +1870,11 @@ siop_add_dev(sc, target, lun)
sc->script_free_hi)) {
/*
- * not enouth space, probably not worth dealing with it.
+ * not enough space, probably not worth dealing with it.
* We can hold 13 tagged-queuing capable devices in the 4k RAM.
*/